@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Util qw{xml_escape};
 use Scalar::Util qw{blessed};
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # Method used to retrieve the object's PK
 my $METHOD = 'id';
@@ -35,7 +35,6 @@ sub register
 	    my $dom_id = $self->_generate_dom_id($obj, %config);
 
 	    xml_escape($dom_id);
-	    $dom_id;
     });
 
     $app->helper( 		 
@@ -46,7 +45,6 @@ sub register
 	    my $dom_class = $self->_generate_dom_class($obj, %config);
 
 	    xml_escape($dom_class);
-	    $dom_class;
     });		
 }
 
@@ -70,12 +68,12 @@ sub _generate_dom_id
 	    push @suffix, $obj->$method;
 	}
 	
-	local $_;
 	@suffix = grep defined, @suffix;
 
 	if(@suffix) {
 	    $dom_id .= $delimiter;
 	    $dom_id .= join '', @suffix;
+            $dom_id =~ s/\s+/$delimiter/g;
 	}
     }
 
@@ -97,7 +95,6 @@ sub _generate_dom_class
     }
  
     # Split the package name on camelcase bounderies
-    local $_;    
     my $dom_class = join $delimiter, map {
 	s/([^A-Z])([A-Z])/$1$delimiter$2/g;
 	s/([A-Z])([A-Z][^A-Z])/$1$delimiter$2/g;
